Class: Google::Apis::VersionhistoryV1::Release
- Inherits:
-
Object
- Object
- Google::Apis::VersionhistoryV1::Release
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/versionhistory_v1/classes.rb,
lib/google/apis/versionhistory_v1/representations.rb,
lib/google/apis/versionhistory_v1/representations.rb
Overview
A Release is owned by a Version. A Release contains information about the release(s) of its parent version. This includes when the release began and ended, as well as what percentage it was released at. If the version is released again, or if the serving percentage changes, it will create another release under the version.
Instance Attribute Summary collapse
-
#fraction ⇒ Float
Rollout fraction.
-
#fraction_group ⇒ Fixnum
Rollout fraction group.
-
#name ⇒ String
Release name.
-
#pinnable ⇒ Boolean
(also: #pinnable?)
Whether or not the release was available for version pinning.
-
#rollout_data ⇒ Array<Google::Apis::VersionhistoryV1::RolloutData>
Rollout-related metadata.
-
#serving ⇒ Google::Apis::VersionhistoryV1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#version ⇒ String
String containing just the version number.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Release
constructor
A new instance of Release.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Release
Returns a new instance of Release.
267 268 269 |
# File 'lib/google/apis/versionhistory_v1/classes.rb', line 267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fraction ⇒ Float
Rollout fraction. This fraction indicates the fraction of people that should
receive this version in this release. If the fraction is not specified in
ReleaseManager, the API will assume fraction is 1.
Corresponds to the JSON property fraction
226 227 228 |
# File 'lib/google/apis/versionhistory_v1/classes.rb', line 226 def fraction @fraction end |
#fraction_group ⇒ Fixnum
Rollout fraction group. Only fractions with the same fraction_group are
statistically comparable: there may be non-fractional differences between
different fraction groups.
Corresponds to the JSON property fractionGroup
233 234 235 |
# File 'lib/google/apis/versionhistory_v1/classes.rb', line 233 def fraction_group @fraction_group end |
#name ⇒ String
Release name. Format is "product/platforms/platform/channels/channel/
versions/version/releases/release"
Corresponds to the JSON property name
239 240 241 |
# File 'lib/google/apis/versionhistory_v1/classes.rb', line 239 def name @name end |
#pinnable ⇒ Boolean Also known as: pinnable?
Whether or not the release was available for version pinning.
Corresponds to the JSON property pinnable
244 245 246 |
# File 'lib/google/apis/versionhistory_v1/classes.rb', line 244 def pinnable @pinnable end |
#rollout_data ⇒ Array<Google::Apis::VersionhistoryV1::RolloutData>
Rollout-related metadata. Some releases are part of one or more A/B rollouts.
This field contains the names and data describing this release's role in any
rollouts.
Corresponds to the JSON property rolloutData
252 253 254 |
# File 'lib/google/apis/versionhistory_v1/classes.rb', line 252 def rollout_data @rollout_data end |
#serving ⇒ Google::Apis::VersionhistoryV1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property serving
260 261 262 |
# File 'lib/google/apis/versionhistory_v1/classes.rb', line 260 def serving @serving end |
#version ⇒ String
String containing just the version number. e.g. "84.0.4147.38"
Corresponds to the JSON property version
265 266 267 |
# File 'lib/google/apis/versionhistory_v1/classes.rb', line 265 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
272 273 274 275 276 277 278 279 280 |
# File 'lib/google/apis/versionhistory_v1/classes.rb', line 272 def update!(**args) @fraction = args[:fraction] if args.key?(:fraction) @fraction_group = args[:fraction_group] if args.key?(:fraction_group) @name = args[:name] if args.key?(:name) @pinnable = args[:pinnable] if args.key?(:pinnable) @rollout_data = args[:rollout_data] if args.key?(:rollout_data) @serving = args[:serving] if args.key?(:serving) @version = args[:version] if args.key?(:version) end |